@@ -136,11 +136,12 @@ class LGBMClassifierCV(object):
         importances = self.feature_importances.tolist()
         if feature_names is None:
             feature_names = list(map(lambda x: f'F_{x}', range(len(importances))))
-        _ = list(zip(importances, feature_names))
-        df = pd.DataFrame(_, columns=columns).sort_values('Importances', 0, False)
+
+        _ = sorted(zip(importances, feature_names), reverse=True)
+        self.df_feature_importances = pd.DataFrame(_, columns=columns)
 
         plt.figure(figsize=(12, topk // 5) if figsize is None else figsize)
-        sns.barplot(*columns, data=df[:topk])
+        sns.barplot(*columns, data=self.df_feature_importances[:topk])
         plt.title('Features Importances\n')
         plt.tight_layout()
         if pic_name is None:
